package net.knarcraft.blacksmith.event;

import net.citizensnpcs.api.npc.NPC;
import org.bukkit.entity.Player;
import org.bukkit.event.HandlerList;
import org.jetbrains.annotations.NotNull;

/**
 * The event triggered when a blacksmith reforging starts
 */
public class BlacksmithReforgeStartEvent extends AbstractBlacksmithPluginEvent implements ActionStartEvent {

    private static final HandlerList handlers = new HandlerList();
    private final long durationTicks;

    /**
     * Instantiates a new blacksmith reforge start event
     *
     * @param npc           <p>The NPC involved in the event</p>
     * @param player        <p>The player involved in the event</p>
     * @param durationTicks <p>The duration of the reforge</p>
     */
    public BlacksmithReforgeStartEvent(@NotNull NPC npc, @NotNull Player player, long durationTicks) {
        super(npc, player);
        this.durationTicks = durationTicks;
    }

    @Override
    public long getActionDurationTicks() {
        return durationTicks;
    }

    /**
     * Gets a handler-list containing all event handlers
     *
     * @return <p>A handler-list with all event handlers</p>
     */
    @NotNull
    @SuppressWarnings("unused")
    public static HandlerList getHandlerList() {
        return handlers;
    }

    @Override
    @NotNull
    public HandlerList getHandlers() {
        return handlers;
    }

}
